'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var PropTypes = require('prop-types');
var cs = require('classnames');

function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefault(React);
var PropTypes__default = /*#__PURE__*/_interopDefault(PropTypes);
var cs__default = /*#__PURE__*/_interopDefault(cs);

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};
  var target = _objectWithoutPropertiesLoose(source, excluded);
  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

const TIME_TO_CLOSE_MESSAGE = 3000;
const DELAY_FOR_DBCLICK = 200;
const CLICK_TO_CELL_EDIT = 'click';
const DBCLICK_TO_CELL_EDIT = 'dbclick';
const EDITTYPE = {
  TEXT: 'text',
  SELECT: 'select',
  TEXTAREA: 'textarea',
  CHECKBOX: 'checkbox',
  DATE: 'date'
};

const CellEditContext = /*#__PURE__*/React__default['default'].createContext();
var createContext = ((_, dataOperator, isRemoteCellEdit = () => false, handleCellChange) => {
  class CellEditProvider extends React__default['default'].Component {
    constructor(...args) {
      super(...args);
      this.state = {
        ridx: null,
        cidx: null,
        message: null
      };

      this.handleCellUpdate = (row, column, newValue) => {
        const newValueWithType = dataOperator.typeConvert(column.type, newValue);
        const {
          cellEdit
        } = this.props;
        const {
          beforeSaveCell
        } = cellEdit.options;

        const oldValue = _.get(row, column.dataField);

        const beforeSaveCellDone = (result = true) => {
          if (result) {
            this.doUpdate(row, column, newValueWithType);
          } else {
            this.escapeEditing();
          }
        };

        if (_.isFunction(beforeSaveCell)) {
          const result = beforeSaveCell(oldValue, newValueWithType, row, column, beforeSaveCellDone);

          if (_.isObject(result) && result.async) {
            return;
          }
        }

        this.doUpdate(row, column, newValueWithType);
      };

      this.doUpdate = (row, column, newValue) => {
        const {
          keyField,
          cellEdit,
          data
        } = this.props;
        const {
          afterSaveCell
        } = cellEdit.options;

        const rowId = _.get(row, keyField);

        const oldValue = _.get(row, column.dataField);

        if (isRemoteCellEdit()) {
          handleCellChange(rowId, column.dataField, newValue);
        } else {
          dataOperator.editCell(data, keyField, rowId, column.dataField, newValue);
          if (_.isFunction(afterSaveCell)) afterSaveCell(oldValue, newValue, row, column);
          this.completeEditing();
        }
      };

      this.completeEditing = () => {
        this.setState(() => ({
          ridx: null,
          cidx: null,
          message: null
        }));
      };

      this.startEditing = (ridx, cidx) => {
        const editing = () => {
          this.setState(() => ({
            ridx,
            cidx
          }));
        };

        const {
          selectRow
        } = this.props;
        if (!selectRow || selectRow.clickToEdit || !selectRow.clickToSelect) editing();
      };

      this.escapeEditing = () => {
        this.setState(() => ({
          ridx: null,
          cidx: null
        }));
      };
    }

    // UNSAFE_componentWillReceiveProps(nextProps) {
    // static getDerivedStateFromProps(nextProps) {
    componentDidUpdate() {
      if (this.props.cellEdit && isRemoteCellEdit()) {
        var _this$props, _this$props$cellEdit, _this$props$cellEdit$;

        if ((_this$props = this.props) !== null && _this$props !== void 0 && (_this$props$cellEdit = _this$props.cellEdit) !== null && _this$props$cellEdit !== void 0 && (_this$props$cellEdit$ = _this$props$cellEdit.options) !== null && _this$props$cellEdit$ !== void 0 && _this$props$cellEdit$.errorMessage) {
          // eslint-disable-next-line react/no-did-update-set-state
          this.setState(() => ({
            message: this.props.cellEdit.options.errorMessage
          }));
        } else {
          this.escapeEditing();
        }
      }
    }

    render() {
      const _this$props2 = this.props,
            {
        cellEdit: {
          options: {
            nonEditableRows,
            errorMessage
          }
        },
        children
      } = _this$props2,
            optionsRest = _objectWithoutProperties(_this$props2.cellEdit.options, ["nonEditableRows", "errorMessage"]),
            cellEditRest = _objectWithoutProperties(_this$props2.cellEdit, ["options"]);

      const newCellEdit = _objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({}, optionsRest), cellEditRest), this.state), {}, {
        nonEditableRows: _.isDefined(nonEditableRows) ? nonEditableRows() : [],
        onStart: this.startEditing,
        onEscape: this.escapeEditing,
        onUpdate: this.handleCellUpdate
      });

      return /*#__PURE__*/React__default['default'].createElement(CellEditContext.Provider, {
        value: _objectSpread2({}, newCellEdit)
      }, children);
    }

  }

  CellEditProvider.propTypes = {
    data: PropTypes__default['default'].array.isRequired,
    selectRow: PropTypes__default['default'].object,
    options: PropTypes__default['default'].shape({
      mode: PropTypes__default['default'].oneOf([CLICK_TO_CELL_EDIT, DBCLICK_TO_CELL_EDIT]).isRequired,
      onErrorMessageDisappear: PropTypes__default['default'].func,
      blurToSave: PropTypes__default['default'].bool,
      beforeSaveCell: PropTypes__default['default'].func,
      afterSaveCell: PropTypes__default['default'].func,
      onStartEdit: PropTypes__default['default'].func,
      nonEditableRows: PropTypes__default['default'].func,
      timeToCloseMessage: PropTypes__default['default'].number,
      errorMessage: PropTypes__default['default'].any
    })
  };
  return {
    Provider: CellEditProvider
  };
});
const {
  Consumer
} = CellEditContext;

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var withRowLevelCellEdit = ((Component, selectRowEnabled) => {
  const renderWithCellEdit = (props, cellEdit) => {
    const key = props.value;
    const editableRow = !(cellEdit.nonEditableRows.length > 0 && cellEdit.nonEditableRows.indexOf(key) > -1);
    const attrs = {};

    if (selectRowEnabled && cellEdit.mode === DBCLICK_TO_CELL_EDIT) {
      attrs.DELAY_FOR_DBCLICK = DELAY_FOR_DBCLICK;
    }

    return /*#__PURE__*/React__default['default'].createElement(Component, _extends({}, props, attrs, {
      editingRowIdx: cellEdit.ridx,
      editingColIdx: cellEdit.cidx,
      editable: editableRow,
      onStart: cellEdit.onStart,
      clickToEdit: cellEdit.mode === CLICK_TO_CELL_EDIT,
      dbclickToEdit: cellEdit.mode === DBCLICK_TO_CELL_EDIT
    }));
  };

  function withConsumer(props) {
    return /*#__PURE__*/React__default['default'].createElement(Consumer, null, cellEdit => renderWithCellEdit(props, cellEdit));
  }

  withConsumer.displayName = 'WithCellEditingRowConsumer';
  return withConsumer;
});

class DropDownEditor extends React.Component {
  constructor(props) {
    super(props);

    this.setOptions = options => {
      this.setState({
        options
      });
    };

    let {
      options: _options
    } = props;

    if (props.getOptions) {
      _options = props.getOptions(this.setOptions, {
        row: props.row,
        column: props.column
      }) || [];
    }

    this.state = {
      options: _options
    };
  }

  componentDidMount() {
    const {
      defaultValue,
      didMount
    } = this.props;
    this.select.value = defaultValue;
    this.select.focus();
    if (didMount) didMount();
  }

  getValue() {
    return this.select.value;
  }

  render() {
    const _this$props = this.props,
          {
      defaultValue,
      didMount,
      getOptions,
      className
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["defaultValue", "didMount", "getOptions", "className"]);

    const {
      options
    } = this.state;
    const editorClass = cs__default['default']('form-control editor edit-select', className);

    const attr = _objectSpread2(_objectSpread2({}, rest), {}, {
      className: editorClass
    });

    return /*#__PURE__*/React__default['default'].createElement("select", _extends({}, attr, {
      ref: node => this.select = node,
      defaultValue: defaultValue
    }), options.map(({
      label,
      value
    }) => /*#__PURE__*/React__default['default'].createElement("option", {
      key: value,
      value: value
    }, label)));
  }

}

DropDownEditor.propTypes = {
  row: PropTypes__default['default'].object.isRequired,
  column: PropTypes__default['default'].object.isRequired,
  defaultValue: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].number]),
  className: PropTypes__default['default'].string,
  style: PropTypes__default['default'].object,
  options: PropTypes__default['default'].oneOfType([PropTypes__default['default'].arrayOf(PropTypes__default['default'].shape({
    label: PropTypes__default['default'].string,
    value: PropTypes__default['default'].any
  }))]),
  didMount: PropTypes__default['default'].func,
  getOptions: PropTypes__default['default'].func
};
DropDownEditor.defaultProps = {
  className: '',
  defaultValue: '',
  style: {},
  options: [],
  didMount: undefined,
  getOptions: undefined
};

class TextAreaEditor extends React.Component {
  constructor(...args) {
    super(...args);

    this.handleKeyDown = e => {
      const {
        onKeyDown
      } = this.props;
      if (e.keyCode === 13 && !e.shiftKey) return;

      if (onKeyDown) {
        onKeyDown(e);
      }
    };
  }

  componentDidMount() {
    const {
      defaultValue,
      didMount,
      autoSelectText
    } = this.props;
    this.text.value = defaultValue;
    this.text.focus();
    if (autoSelectText) this.text.select();
    if (didMount) didMount();
  }

  getValue() {
    return this.text.value;
  }

  render() {
    const _this$props = this.props,
          {
      defaultValue,
      didMount,
      className,
      autoSelectText
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["defaultValue", "didMount", "className", "autoSelectText"]);

    const editorClass = cs__default['default']('form-control editor edit-textarea', className);
    return /*#__PURE__*/React__default['default'].createElement("textarea", _extends({
      ref: node => this.text = node,
      type: "textarea",
      className: editorClass
    }, rest, {
      onKeyDown: this.handleKeyDown
    }));
  }

}

TextAreaEditor.propTypes = {
  className: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].object]),
  defaultValue: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].number]),
  onKeyDown: PropTypes__default['default'].func,
  autoSelectText: PropTypes__default['default'].bool,
  didMount: PropTypes__default['default'].func
};
TextAreaEditor.defaultProps = {
  className: '',
  defaultValue: '',
  autoSelectText: false,
  onKeyDown: undefined,
  didMount: undefined
};

class CheckBoxEditor extends React.Component {
  constructor(props) {
    super(props);
    this.checkbox = /*#__PURE__*/React.createRef();

    this.handleChange = e => {
      const {
        onChange
      } = this.props;
      if (onChange) onChange(e);
      const {
        target
      } = e;
      this.setState(() => ({
        checked: target.checked
      }));
    };

    this.state = {
      checked: props.defaultValue.toString() === props.value.split(':')[0]
    };
  }

  static getDerivedStateFromProps(props) {
    return {
      checked: props.defaultValue.toString() === props.value.split(':')[0]
    };
  }

  componentDidMount() {
    var _this$checkbox$curren;

    const {
      didMount
    } = this.props;
    (_this$checkbox$curren = this.checkbox.current) === null || _this$checkbox$curren === void 0 ? void 0 : _this$checkbox$curren.focus();
    if (didMount) didMount();
  }

  getValue() {
    var _this$checkbox$curren2;

    const {
      value
    } = this.props;
    const [positive, negative] = value.split(':');
    return (_this$checkbox$curren2 = this.checkbox.current) !== null && _this$checkbox$curren2 !== void 0 && _this$checkbox$curren2.checked ? positive : negative;
  }

  render() {
    const _this$props = this.props,
          {
      defaultValue,
      didMount,
      className
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["defaultValue", "didMount", "className"]);

    const {
      checked
    } = this.state;
    const editorClass = cs__default['default']('editor edit-chseckbox checkbox', className);
    return /*#__PURE__*/React__default['default'].createElement("input", _extends({
      ref: this.checkbox,
      type: "checkbox",
      className: editorClass
    }, rest, {
      checked: checked,
      onChange: this.handleChange
    }));
  }

}

CheckBoxEditor.propTypes = {
  className: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].object]),
  value: PropTypes__default['default'].string,
  defaultValue: PropTypes__default['default'].any,
  onChange: PropTypes__default['default'].func,
  didMount: PropTypes__default['default'].func
};
CheckBoxEditor.defaultProps = {
  className: '',
  value: 'on:off',
  defaultValue: false,
  onChange: undefined,
  didMount: undefined
};

class DateEditor extends React.Component {
  constructor(...args) {
    super(...args);
    this.date = /*#__PURE__*/React.createRef();
  }

  componentDidMount() {
    const {
      defaultValue,
      didMount
    } = this.props;
    this.date.current.valueAsDate = new Date(defaultValue);
    this.date.current.focus();
    if (didMount) didMount();
  }

  getValue() {
    var _this$date$curent;

    return (_this$date$curent = this.date.curent) === null || _this$date$curent === void 0 ? void 0 : _this$date$curent.value;
  }

  render() {
    const _this$props = this.props,
          {
      defaultValue,
      didMount,
      className
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["defaultValue", "didMount", "className"]);

    const editorClass = cs__default['default']('form-control editor edit-date', className);
    return /*#__PURE__*/React__default['default'].createElement("input", _extends({
      ref: this.date,
      type: "date",
      className: editorClass
    }, rest));
  }

}

DateEditor.propTypes = {
  className: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].object]),
  defaultValue: PropTypes__default['default'].string,
  didMount: PropTypes__default['default'].func
};
DateEditor.defaultProps = {
  className: '',
  defaultValue: '',
  didMount: undefined
};

class TextEditor extends React.Component {
  componentDidMount() {
    const {
      defaultValue,
      didMount,
      autoSelectText
    } = this.props;
    this.text.value = defaultValue;
    this.text.focus();
    if (autoSelectText) this.text.select();
    if (didMount) didMount();
  }

  getValue() {
    return this.text.value;
  }

  render() {
    const _this$props = this.props,
          {
      defaultValue,
      didMount,
      className,
      autoSelectText
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["defaultValue", "didMount", "className", "autoSelectText"]);

    const editorClass = cs__default['default']('form-control editor edit-text', className);
    return /*#__PURE__*/React__default['default'].createElement("input", _extends({
      ref: node => this.text = node,
      type: "text",
      className: editorClass
    }, rest));
  }

}

TextEditor.propTypes = {
  className: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].object]),
  defaultValue: PropTypes__default['default'].oneOfType([PropTypes__default['default'].string, PropTypes__default['default'].number]),
  autoSelectText: PropTypes__default['default'].bool,
  didMount: PropTypes__default['default'].func
};
TextEditor.defaultProps = {
  className: null,
  defaultValue: '',
  autoSelectText: false,
  didMount: undefined
};

/* eslint no-return-assign: 0 */

const EditorIndicator = ({
  invalidMessage
}) => /*#__PURE__*/React__default['default'].createElement("div", {
  className: "alert alert-danger in",
  role: "alert"
}, /*#__PURE__*/React__default['default'].createElement("strong", null, invalidMessage));

EditorIndicator.propTypes = {
  invalidMessage: PropTypes__default['default'].string
};
EditorIndicator.defaultProps = {
  invalidMessage: null
};

var createEditingCell$1 = ((_, onStartEdit) => {
  class EditingCell extends React.Component {
    constructor(...args) {
      super(...args);
      this.indicatorTimer = null;
      this.state = {
        invalidMessage: null
      };

      this.handleBlur = () => {
        const {
          onEscape,
          blurToSave
        } = this.props;

        if (blurToSave) {
          this.beforeComplete(this.editor.getValue());
        } else {
          onEscape();
        }
      };

      this.handleKeyDown = e => {
        const {
          onEscape
        } = this.props;

        if (e.keyCode === 27) {
          // ESC
          onEscape();
        } else if (e.keyCode === 13) {
          // ENTER
          this.beforeComplete(this.editor.getValue());
        }
      };

      this.handleClick = e => {
        if (e.target.tagName !== 'TD') {
          // To avoid the row selection event be triggered,
          // When user define selectRow.clickToSelect and selectRow.clickToEdit
          // We shouldn't trigger selection event even if user click on the cell editor(input)
          e.stopPropagation();
        }
      };

      this.clearTimer = () => {
        if (this.indicatorTimer) {
          clearTimeout(this.indicatorTimer);
        }
      };

      this.displayErrorMessage = message => {
        this.setState(() => ({
          invalidMessage: message
        }));
        this.createTimer();
      };

      this.asyncbeforeCompete = newValue => (result = {
        valid: true
      }) => {
        const {
          valid,
          message
        } = result;
        const {
          onUpdate,
          row,
          column
        } = this.props;

        if (!valid) {
          this.displayErrorMessage(message);
          return;
        }

        onUpdate(row, column, newValue);
      };

      this.beforeComplete = newValue => {
        const {
          onUpdate,
          row,
          column
        } = this.props;

        if (_.isFunction(column.validator)) {
          const validateForm = column.validator(newValue, row, column, this.asyncbeforeCompete(newValue));

          if (_.isObject(validateForm)) {
            if (validateForm.async) {
              return;
            }

            if (!validateForm.valid) {
              this.displayErrorMessage(validateForm.message);
              return;
            }
          }
        }

        onUpdate(row, column, newValue);
      };
    }

    static getDerivedStateFromProps(props) {
      if (_.isDefined(props === null || props === void 0 ? void 0 : props.message)) {
        return {
          invalidMessage: props === null || props === void 0 ? void 0 : props.message
        };
      }

      return null;
    } // UNSAFE_componentWillReceiveProps({ message }) {


    componentDidUpdate({
      message
    }) {
      if (_.isDefined(message)) {
        this.createTimer(); // eslint-disable-next-line react/no-did-update-set-state

        this.setState(() => ({
          invalidMessage: message
        }));
      }
    }

    componentWillUnmount() {
      this.clearTimer();
    }

    createTimer() {
      this.clearTimer();
      const {
        timeToCloseMessage,
        onErrorMessageDisappear
      } = this.props;
      this.indicatorTimer = _.sleep(() => {
        this.setState(() => ({
          invalidMessage: null
        }));
        if (_.isFunction(onErrorMessageDisappear)) onErrorMessageDisappear();
      }, timeToCloseMessage);
    }

    render() {
      const {
        invalidMessage
      } = this.state;
      let editor;
      const {
        row,
        column,
        className,
        style,
        rowIndex,
        columnIndex,
        autoSelectText
      } = this.props;
      const {
        dataField
      } = column;

      const value = _.get(row, dataField);

      const hasError = _.isDefined(invalidMessage);

      let customEditorClass = column.editorClasses || '';

      if (_.isFunction(column.editorClasses)) {
        customEditorClass = column.editorClasses(value, row, rowIndex, columnIndex);
      }

      let editorStyle = column.editorStyle || {};

      if (_.isFunction(column.editorStyle)) {
        editorStyle = column.editorStyle(value, row, rowIndex, columnIndex);
      }

      const editorClass = cs__default['default']({
        animated: hasError,
        shake: hasError
      }, customEditorClass);
      let editorProps = {
        ref: node => this.editor = node,
        defaultValue: value,
        style: editorStyle,
        className: editorClass,
        onKeyDown: this.handleKeyDown,
        onBlur: this.handleBlur
      };

      if (onStartEdit) {
        editorProps.didMount = () => onStartEdit(row, column, rowIndex, columnIndex);
      }

      const isDefaultEditorDefined = _.isObject(column.editor);

      if (isDefaultEditorDefined) {
        editorProps = _objectSpread2(_objectSpread2({}, editorProps), column.editor);
      } else if (_.isFunction(column.editorRenderer)) {
        editorProps = _objectSpread2(_objectSpread2({}, editorProps), {}, {
          onUpdate: this.beforeComplete
        });
      }

      if (_.isFunction(column.editorRenderer)) {
        editor = column.editorRenderer(editorProps, value, row, column, rowIndex, columnIndex);
      } else if (isDefaultEditorDefined && column.editor.type === EDITTYPE.SELECT) {
        editor = /*#__PURE__*/React__default['default'].createElement(DropDownEditor, _extends({}, editorProps, {
          row: row,
          column: column
        }));
      } else if (isDefaultEditorDefined && column.editor.type === EDITTYPE.TEXTAREA) {
        editor = /*#__PURE__*/React__default['default'].createElement(TextAreaEditor, _extends({}, editorProps, {
          autoSelectText: autoSelectText
        }));
      } else if (isDefaultEditorDefined && column.editor.type === EDITTYPE.CHECKBOX) {
        editor = /*#__PURE__*/React__default['default'].createElement(CheckBoxEditor, editorProps);
      } else if (isDefaultEditorDefined && column.editor.type === EDITTYPE.DATE) {
        editor = /*#__PURE__*/React__default['default'].createElement(DateEditor, editorProps);
      } else {
        editor = /*#__PURE__*/React__default['default'].createElement(TextEditor, _extends({}, editorProps, {
          autoSelectText: autoSelectText
        }));
      }

      return /*#__PURE__*/React__default['default'].createElement("td", {
        className: cs__default['default']('react-bootstrap-table-editing-cell', className),
        style: style,
        onClick: this.handleClick
      }, editor, hasError ? /*#__PURE__*/React__default['default'].createElement(EditorIndicator, {
        invalidMessage: invalidMessage
      }) : null);
    }

  }

  EditingCell.propTypes = {
    row: PropTypes__default['default'].object.isRequired,
    rowIndex: PropTypes__default['default'].number.isRequired,
    column: PropTypes__default['default'].object.isRequired,
    columnIndex: PropTypes__default['default'].number.isRequired,
    onUpdate: PropTypes__default['default'].func.isRequired,
    onEscape: PropTypes__default['default'].func.isRequired,
    timeToCloseMessage: PropTypes__default['default'].number,
    autoSelectText: PropTypes__default['default'].bool,
    className: PropTypes__default['default'].string,
    style: PropTypes__default['default'].object
  };
  EditingCell.defaultProps = {
    timeToCloseMessage: TIME_TO_CLOSE_MESSAGE,
    className: null,
    autoSelectText: false,
    style: {}
  };
  return EditingCell;
});

var createEditingCell = ((_, onStartEdit) => {
  const EditingCell = createEditingCell$1(_, onStartEdit);

  const renderWithEditingCell = (props, cellEdit) => {
    const content = _.get(props.row, props.column.dataField);

    let editCellstyle = props.column.editCellStyle || {};
    let editCellclasses = props.column.editCellClasses;

    if (_.isFunction(props.column.editCellStyle)) {
      editCellstyle = props.column.editCellStyle(content, props.row, props.rowIndex, props.columnIndex);
    }

    if (_.isFunction(props.column.editCellClasses)) {
      editCellclasses = props.column.editCellClasses(content, props.row, props.rowIndex, props.columnIndex);
    }

    return /*#__PURE__*/React__default['default'].createElement(EditingCell, _extends({}, props, {
      className: editCellclasses,
      style: editCellstyle
    }, cellEdit));
  };

  return props => /*#__PURE__*/React__default['default'].createElement(Consumer, null, cellEdit => renderWithEditingCell(props, cellEdit));
});

var index = ((options = {}) => ({
  createContext,
  createEditingCell,
  withRowLevelCellEdit,
  DBCLICK_TO_CELL_EDIT,
  DELAY_FOR_DBCLICK,
  options
}));
const Type = EDITTYPE;

exports.Type = Type;
exports.default = index;
